## 0.8.6 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.8.4 (2021-12-06)

caldav: Update DAVError and AuthorizationError (#6508)

## 0.8.3 (2021-11-09)

Fix typos (#6263)

Found via `codespell -q 3 -L alo,asend,ba,nams,spawnve`

## 0.8.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

